#[non_exhaustive]pub struct PresenceSharingEventContent {
pub share_locally: bool,
pub users: BTreeMap<OwnedUserId, UserPresenceSharingState>,
pub rooms: BTreeMap<OwnedRoomId, RoomPresenceSharingState>,
pub servers: BTreeMap<OwnedServerName, ServerPresenceSharingState>,
}Expand description
The content of the m.presence.sharing account data key.
This uses the unstable prefix defined in MSC4495.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.Whether presence should be shared with all users on the local homeserver.
users: BTreeMap<OwnedUserId, UserPresenceSharingState>Configuration for sharing presence with users.
rooms: BTreeMap<OwnedRoomId, RoomPresenceSharingState>Configuration for sharing presence with rooms.
Sharing presence with rooms also depends on the room’s presence sharing hint.
servers: BTreeMap<OwnedServerName, ServerPresenceSharingState>Configuration for sharing presence with servers.
Implementations
Sourceimpl PresenceSharingEventContent
impl PresenceSharingEventContent
Sourcepub fn new(
share_locally: bool,
users: BTreeMap<OwnedUserId, UserPresenceSharingState>,
rooms: BTreeMap<OwnedRoomId, RoomPresenceSharingState>,
servers: BTreeMap<OwnedServerName, ServerPresenceSharingState>,
) -> Self
pub fn new( share_locally: bool, users: BTreeMap<OwnedUserId, UserPresenceSharingState>, rooms: BTreeMap<OwnedRoomId, RoomPresenceSharingState>, servers: BTreeMap<OwnedServerName, ServerPresenceSharingState>, ) -> Self
Creates a new PresenceSharingEventContent with the given parameters.